Learn R Programming

bnlearn (version 5.2)

bn.boot: Nonparametric bootstrap of Bayesian networks

Description

Apply a user-specified function to the Bayesian network structures learned from bootstrap samples of the original data.

Usage

bn.boot(data, statistic, R = 200, m = nrow(data), algorithm,
  algorithm.args = list(), statistic.args = list(), cluster,
  debug = FALSE)

Value

A list containing the results of the calls to statistic.

Arguments

data

a data frame containing the variables in the model.

statistic

a function or a character string (the name of a function) to be applied to each bootstrap replicate.

R

a positive integer, the number of bootstrap replicates.

m

a positive integer, the size of each bootstrap replicate.

algorithm

a character string, the learning algorithm to be applied to the bootstrap replicates. See structure learning and the documentation of each algorithm for details.

algorithm.args

a list of extra arguments to be passed to the learning algorithm.

statistic.args

a list of extra arguments to be passed to the function specified by statistic.

cluster

an optional cluster object from package parallel.

debug

a boolean value. If TRUE, a lot of debugging output is printed. Otherwise, the function is completely silent.

Author

Marco Scutari

Details

The first argument of statistic is the bn object encoding the network structure learned from the bootstrap sample. The arguments specified in statistic.args are extracted from the list and passed to statistic as subsequent arguments.

References

Friedman N, Goldszmidt M, Wyner A (1999). "Data Analysis with Bayesian Networks: A Bootstrap Approach." Proceedings of the 15th Annual Conference on Uncertainty in Artificial Intelligence, 196--201.

See Also

bn.cv, rbn.

Examples

Run this code
if (FALSE) {
data(learning.test)
bn.boot(data = learning.test, R = 2, m = 500, algorithm = "gs",
  statistic = arcs)
}

Run the code above in your browser using DataLab