Learn R Programming

bnlearn (version 5.2)

bn.fit plots: Plot fitted Bayesian networks

Description

Plot functions for the bn.fit, bn.fit.dnode and bn.fit.gnode classes, based on the lattice package.

Usage

## for Gaussian Bayesian networks.
bn.fit.qqplot(fitted, xlab = "Theoretical Quantiles",
  ylab = "Sample Quantiles", main, ...)
bn.fit.histogram(fitted, density = TRUE, xlab = "Residuals",
  ylab = ifelse(density, "Density", ""), main, ...)
bn.fit.xyplot(fitted, xlab = "Fitted values", ylab = "Residuals", main, ...)
## for discrete (multinomial and ordinal) Bayesian networks.
bn.fit.barchart(fitted, xlab = "Probabilities", ylab = "Levels", main, ...)
bn.fit.dotplot(fitted, xlab = "Probabilities", ylab = "Levels", main, ...)

Value

The lattice plot objects. Note that if auto-printing is turned off (for example, when the code is loaded with the source function), the return value must be printed explicitly for the plot to be displayed.

Arguments

fitted

an object of class bn.fit, bn.fit.dnode or bn.fit.gnode.

xlab, ylab, main

the label of the x axis, of the y axis, and the plot title.

density

a boolean value. If TRUE, the histogram uses relative frequencies and shows the matching normal density.

...

additional arguments to be passed to lattice functions.

Author

Marco Scutari

Details

bn.fit.qqplot() draws a quantile-quantile plot of the residuals.

bn.fit.histogram() draws a histogram of the residuals, using either absolute or relative frequencies.

bn.fit.xyplot() plots the residuals versus the fitted values.

bn.fit.barchart() and bn.fit.dotplot plot the probabilities in the conditional probability table associated with each node.

See Also

bn.fit, bn.fit class.