The structure of an object of S3 class bn.strength.
Marco Scutari
An object of class bn.strength is a data frame with the following
columns and one row for each arc:
from, to: the nodes incident on the arc.
strength: the strength of the arc. See
arc.strength, boot.strength,
custom.strength and strength.plot
for details.
and some additional attributes:
nodes: a vector of character strings, the labels of the nodes
of the network(s) the strength was computed from.
method: a character string, the method used to compute the
strength coefficients. It can be equal to "test", "score" or
"bootstrap".
threshold: a numeric value, the threshold for determining
whether a strength coefficient is significant.
An optional column called direction may also be present, giving the
probability of the arc's irection given its presence in the graph.
Only the plot() method is defined for this class; therefore, it can
be manipulated as a standard data frame.