| bn.boot | R Documentation |
Apply a user-specified function to the Bayesian network structures learned from bootstrap samples of the original data.
bn.boot(data, statistic, R = 200, m = nrow(data), algorithm,
algorithm.args = list(), statistic.args = list(), cluster,
debug = FALSE)
data |
a data frame containing the variables in the model. |
statistic |
a function or a character string (the name of a function) to be applied to each bootstrap replicate. |
R |
a positive integer, the number of bootstrap replicates. |
m |
a positive integer, the size of each bootstrap replicate. |
algorithm |
a character string, the learning algorithm to be applied
to the bootstrap replicates. See |
algorithm.args |
a list of extra arguments to be passed to the learning algorithm. |
statistic.args |
a list of extra arguments to be passed to the function
specified by |
cluster |
an optional cluster object from package parallel. |
debug |
a boolean value. If |
The first argument of statistic is the bn object encoding the
network structure learned from the bootstrap sample. The arguments specified
in statistic.args are extracted from the list and passed to
statistic as subsequent arguments.
A list containing the results of the calls to statistic.
Marco Scutari
Friedman N, Goldszmidt M, Wyner A (1999). "Data Analysis with Bayesian Networks: A Bootstrap Approach." Proceedings of the 15th Annual Conference on Uncertainty in Artificial Intelligence, 196–201.
bn.cv, rbn.
## Not run:
data(learning.test)
bn.boot(data = learning.test, R = 2, m = 500, algorithm = "gs",
statistic = arcs)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.