Learn the structure of a (causal) Bayesian network with DirectLiNGAM.
direct.lingam(x, cluster, whitelist, blacklist, mi, maximize = "alasso",
maximize.args = list(), debug = FALSE)
An object of class bn. See bn-class for details.
a data frame containing the variables in the model.
an optional cluster object from package parallel.
a data frame with two columns (optionally labelled "from" and "to"), containing a set of arcs to be included in the graph.
a data frame with two columns (optionally labelled "from" and "to"), containing a set of arcs not to be included in the graph.
a character string, the label of the mutual information measure used
to identify the topological ordering of the nodes. It can take values
"pwling" (the default) or "gkernel".
a character value, the label of the method used to identify the parents of each node given the causal ordering. The only possible value is "alasso" (adaptive LASSO).
a list of arguments to be passed to the method specified
by maximize. See below for details.
a boolean value. If TRUE, a lot of debugging output is
printed. Otherwise, the function is completely silent.
Marco Scutari
The "alasso" method has the following optional arguments:
gamma: the coefficient of the weights used in the adaptive
LASSO. The default value is 1.
lambda.min.ratio and pmax: identical to the arguments
of the same names in glmnet(), with the same default values and
interpretation.
k: the coefficient of the penalised likelihood score used to
choose the optimal shrinkage in both ridge and LASSO models in the
adaptive LASSO. It defaults to the BIC penalty.
local discovery algorithms, score-based algorithms, constraint-based algorithms, hybrid algorithms.