Learn R Programming

bnlearn (version 5.2.1)

configs: Construct configurations of discrete variables

Description

Create configurations of discrete variables, which are used in modelling conditional probability tables.

Usage

configs(data, all = TRUE)

Value

A factor with one element for each row of data, and levels as specified by all.

Arguments

data

a data frame containing factor columns.

all

a boolean value. If TRUE, all configurations are included as levels in the return value. Otherwise, only configurations that are actually observed are considered.

Author

Marco Scutari

Examples

Run this code
data(learning.test)
configs(learning.test, all = TRUE)
configs(learning.test, all = FALSE)

Run the code above in your browser using DataLab