| cpdag | R Documentation |
Find the equivalence class and the v-structures of a Bayesian network, construct its moral graph, or create a consistent extension of an equivalent class.
cpdag(x, wlbl = FALSE, debug = FALSE)
cextend(x, strict = TRUE, debug = FALSE)
moral(x, debug = FALSE)
cextend.all(x, debug = FALSE)
colliders(x, arcs = FALSE, debug = FALSE)
shielded.colliders(x, arcs = FALSE, debug = FALSE)
unshielded.colliders(x, arcs = FALSE, debug = FALSE)
vstructs(x, arcs = FALSE, debug = FALSE)
x |
an object of class |
arcs |
a boolean value. If |
wlbl |
a boolean value. If |
strict |
a boolean value. If no consistent extension is possible and
|
debug |
a boolean value. If |
Note that arcs whose directions are dictated by the parametric assumptions of
the network are preserved as directed arcs in cpdag(). This means that,
in a conditional Gaussian network, arcs from discrete nodes to continuous
nodes will be treated as whitelisted in their only valid direction.
cextend.all() returns all possible consistent extensions of a CPDAG,
whereas cextend() returns only one. cextend.all() also accepts a
PDAG or an MPDAG (a partially directed graph carrying background knowledge, in
which some directed arcs are not compelled), in which case it enumerates the
consistent extensions that agree with the given arc directions; it stops with
an error if no such extension exists.
cpdag() returns an object of class bn, representing the
equivalence class. moral on the other hand returns the moral graph.
See bn-class for details.
cextend() returns an object of class bn, representing a DAG that
is the consistent extension of x.
cextend.all() returns an object of class bn or a list of objects
of class bn.
vstructs(), colliders(), shielded.colliders() and
unshielded.colliders() return a matrix with either 2 or 3 columns,
according to the value of the arcs argument.
Marco Scutari
Dor D (1992). A Simple Algorithm to Construct a Consistent Extension of a Partially Oriented Graph. UCLA, Cognitive Systems Laboratory.
Koller D, Friedman N (2009). Probabilistic Graphical Models: Principles and Techniques. MIT Press.
Pearl J (2009). Causality: Models, Reasoning and Inference. Cambridge University Press, 2nd edition.
Andersson SA, Madigan D, Perlman MD (1997). "A Characterization of Markov Equivalence Classes for Acyclic Digraphs." The Annals of Statistics, 25(2):505–541.
Wienobst M, Luttermann M, Bannach M, Liskiewicz M (2023). "Efficient Enumeration of Markov Equivalent DAGs." Proceedings of the Thirty-Seventh AAAI Conference on Artificial Intelligence, 12313–12320.
data(learning.test)
dag = hc(learning.test)
cpdag(dag)
vstructs(dag)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.