Learn R Programming

bnlearn (version 5.2)

graphviz.plot: Advanced Bayesian network plots

Description

Plot the graph associated with a Bayesian network using the Rgraphviz package.

Usage

graphviz.plot(x, highlight = NULL, groups, layout = "dot",
  shape = "rectangle", fontsize = 12, main = NULL, sub = NULL,
  render = TRUE)

Arguments

Value

graphviz.plot() returns invisibly the graph object produced from the network passed as the x argument. It can be further modified using the graph and Rgraphviz packages.

Details

The highlight argument is a list with at least one of the following elements:

  • nodes: a character vector, the labels of the nodes to be highlighted.

  • arcs: the arcs to be highlighted (a two-column matrix, whose columns are labelled from and to).

and optionally one or more of the following graphical parameters:

  • col: an integer or character string (the highlight colour for the arcs and the node frames). The default value is red.

  • textCol: an integer or character string (the highlight colour for the labels of the nodes). The default value is black.

  • fill: an integer or character string (the colour used as a background colour for the nodes). The default value is transparent.

  • lwd: a positive number (the line width of highlighted arcs). It overrides the line width settings in strength.plot(). The default value is to use the global settings of Rgraphviz.

  • lty: the line type of highlighted arcs. Possible values are 0, 1, 2, 3, 4, 5, 6, "blank", "solid", "dashed", "dotted", "dotdash", "longdash" and "twodash". The default value is to use the global settings of Rgraphviz.

Note that all these parameters take a single value, which is then applied to all highlighted nodes and arcs.

See Also

plot.bn.