Learn the structure of a Bayesian network with Max-Min Hill Climbing (MMHC), Hybrid HPC (H2PC), and the more general 2-phase Restricted Maximisation (RSMAX2) hybrid algorithms.
rsmax2(x, whitelist, blacklist, restrict = "si.hiton.pc",
maximize = "hc", restrict.args = list(), maximize.args = list(), debug = FALSE)
mmhc(x, whitelist, blacklist, restrict.args = list(),
maximize.args = list(), debug = FALSE)
h2pc(x, whitelist, blacklist, restrict.args = list(),
maximize.args = list(), debug = FALSE)
An object of class bn. See bn-class for details.
a data frame containing the variables in the model.
a data frame with two columns (optionally labelled "from" and "to"), containing a set of arcs to be included in the graph.
a data frame with two columns (optionally labelled "from" and "to"), containing a set of arcs not to be included in the graph.
a character string, the constraint-based or local search
algorithm to be used in the “restrict” phase. See
structure learning and the documentation of each algorithm for
details.
a character string, the score-based algorithm to be used in
the “maximize” phase. Possible values are "hc" and "tabu".
See structure learning for details.
a list of arguments to be passed to the algorithm
specified by restrict, such as test or alpha.
a list of arguments to be passed to the algorithm
specified by maximize, such as restart for hill-climbing or
tabu for tabu search.
a boolean value. If TRUE, a lot of debugging output is
printed. Otherwise, the function is completely silent.
Marco Scutari
local discovery algorithms, score-based algorithms, constraint-based algorithms, causal discovery algorithms.