Overview of the conditional independence tests implemented in bnlearn, with the respective reference publications.
Unless otherwise noted, the reference publication for conditional independence tests is:
Edwards DI (2000). Introduction to Graphical Modelling. Springer, 2nd edition.
Additionally, for continuous permutation tests:
Legendre P (2000). "Comparison of Permutation Methods for the Partial Correlation and Partial Mantel Tests." Journal of Statistical Computation and Simulation, 67:37--73.
and for semiparametric discrete tests:
Tsamardinos I, Borboudakis G (2010). "Permutation Testing Improves Bayesian Network Learning." Machine Learning and Knowledge Discovery in Databases, 322--337.
Available conditional independence tests (and the respective labels) for discrete Bayesian networks (categorical variables) are:
Mutual information: an information-theoretic distance measure.
It's proportional to the log-likelihood ratio (they differ by a factor of
\(2n\)) and is related to the deviance of the tested models. The
asymptotic \(\chi^2\) test ("mi" and "mi-adf"),
the Monte Carlo permutation test ("mc-mi"), the sequential Monte
Carlo permutation test ("smc-mi"), and the semiparametric test
("sp-mi") are implemented. Compared to "mi", "mi-adf"
adjusts the degrees of freedom for structural zeroes and automatically
favours independence if there are fewer than 5 observations per parameter.
Shrinkage estimator for the mutual information
("mi-sh"): an improved asymptotic \(\chi^2\) test
based on the James-Stein estimator for the mutual information.
Hausser J, Strimmer K (2009). "Entropy Inference and the James-Stein Estimator, with Application to Nonlinear Gene Association Networks." Statistical Applications in Genetics and Molecular Biology, 10:1469--1484.
Pearson's \(X^2\): the classical Pearson's
\(X^2\) test for contingency tables. The asymptotic
\(\chi^2\) test ("x2" and "x2-adf", with adjusted
degrees of freedom), the Monte Carlo permutation test ("mc-x2"), the
sequential Monte Carlo permutation test ("smc-x2") and semiparametric
test ("sp-x2") are implemented.
Available conditional independence tests (and the respective labels) for discrete Bayesian networks (ordered factors) are:
Jonckheere-Terpstra: a trend test for ordinal variables. The
asymptotic normal test ("jt"), the Monte Carlo permutation test
("mc-jt") and the sequential Monte Carlo permutation test
("smc-jt") are implemented.
Available conditional independence tests (and the respective labels) for Gaussian Bayesian networks (normal variables) are:
Linear correlation: Pearson's linear correlation. The exact
Student's t test ("cor"), the Monte Carlo permutation test
("mc-cor") and the sequential Monte Carlo permutation test
("smc-cor") are implemented.
Hotelling H (1953). "New Light on the Correlation Coefficient and its Transforms." Journal of the Royal Statistical Society: Series B, 15(2):193--225.
Fisher's Z: a transformation of the linear correlation with
asymptotic normal distribution. The asymptotic normal test ("zf"),
the Monte Carlo permutation test ("mc-zf") and the sequential Monte
Carlo permutation test ("smc-zf") are implemented.
Mutual information: an information-theoretic distance measure.
Again, it is proportional to the log-likelihood ratio (they differ by a
factor of \(2n\)). The asymptotic \(\chi^2\) test
("mi-g"), the Monte Carlo permutation test ("mc-mi-g") and the
sequential Monte Carlo permutation test ("smc-mi-g") are implemented.
Shrinkage estimator for the mutual information
("mi-g-sh"): an improved asymptotic \(\chi^2\) test
based on the James-Stein estimator for the mutual information.
Ledoit O, Wolf M (2003). "Improved Estimation of the Covariance Matrix of Stock Returns with an Application to Portfolio Selection." Journal of Empirical Finance, 10:603--621.
No conditional independence tests are available for zero-inflated Bayesian networks.
Available conditional independence tests (and the respective labels) for conditional Gaussian Bayesian networks (mixed discrete and normal variables) are:
Mutual information: an information-theoretic distance measure.
Again, it is proportional to the log-likelihood ratio (they differ by a
factor of \(2n\)). Only the asymptotic \(\chi^2\) test
("mi-cg") is implemented.