ARACNE and Chow-Liu learn simple network structures from data using pairwise mutual information coefficients.
aracne(x, whitelist, blacklist, mi = NULL, debug = FALSE)
chow.liu(x, whitelist, blacklist, mi = NULL, debug = FALSE)
An object of class bn. See bn-class for details.
a data frame containing the variables in the model.
a data frame with two columns (optionally labelled "from" and "to"), containing a set of arcs to be included in the graph.
a data frame with two columns (optionally labelled "from" and "to"), containing a set of arcs not to be included in the graph.
a character string, the estimator used for the pairwise (that is,
unconditional) mutual information coefficients in the ARACNE and Chow-Liu
algorithms. Possible values are "mi" (discrete mutual information)
and "mi-g" (Gaussian mutual information).
a boolean value. If TRUE, a lot of debugging output is
printed. Otherwise, the function is completely silent.
Marco Scutari
constraint-based algorithms, score-based algorithms, hybrid algorithms, causal discovery algorithms.