Structure learning algorithms for Bayesian network classifiers.
The algorithms are aimed at classification, and favour predictive power over the ability to recover the correct network structure. The implementation in bnlearn assumes that all variables, including the classifiers, are discrete.
Naive Bayes (naive.bayes): a very simple
algorithm that assumes all classifiers are independent and uses the target
variable's posterior probability for classification.
Tree-Augmented Naive Bayes (tree.bayes):
improves over Naive Bayes by using the Chow-Liu algorithm to approximate
the dependence structure of the classifiers.
Friedman N, Geiger D, Goldszmit M (1997). "Bayesian Network Classifiers." Machine Learning, 29:131--163.