ordering: Partial node orderings

node ordering utilitiesR Documentation

Partial node orderings

Description

Find the partial node ordering implied by a network.

Usage

node.ordering(x, debug = FALSE)

Arguments

x

an object of class bn or bn.fit.

debug

a boolean value. If TRUE, a lot of debugging output is printed. Otherwise, the function is completely silent.

Value

node.ordering() returns a vector of character strings, an ordered set of node labels.

Note

node.ordering() supports only completely directed Bayesian networks.

Author(s)

Marco Scutari

Examples

dag = random.graph(LETTERS[1:10])
ord = node.ordering(dag)
ord

bnlearn documentation built on July 13, 2026, 5:08 p.m.