alpha.star: Estimate the optimal imaginary sample size for BDe(u)
Description
Estimate the optimal imaginary sample size for the BDe score, given a network
structure and a data set, assuming a uniform prior.
Usage
alpha.star(x, data, debug = FALSE)
Arguments
Value
alpha.star() returns a positive number, the estimated optimal imaginary
sample size value.
References
Steck H (2008). "Learning the Bayesian Network Structure: Dirichlet Prior
versus Data." Proceedings of the 24th Conference on Uncertainty in
Artificial Intelligence, 511--518.
data(learning.test)
dag = hc(learning.test, score = "bic")
for (i in1:3) {
a = alpha.star(dag, learning.test)
dag = hc(learning.test, score = "bde", iss = a)
}#FOR