Learn R Programming

bnlearn (version 5.2)

configs: Construct configurations of discrete variables

Description

Create configurations of discrete variables, which are used in modelling conditional probability tables.

Usage

configs(data, all = TRUE)

Arguments

Value

A factor with one element for each row of data, and levels as specified by all.

Examples

Run this code
data(learning.test)
configs(learning.test, all = TRUE)
configs(learning.test, all = FALSE)

Run the code above in your browser using DataLab