powered by
Create configurations of discrete variables, which are used in modelling conditional probability tables.
configs(data, all = TRUE)
A factor with one element for each row of data, and levels as specified by all.
data
all
data(learning.test) configs(learning.test, all = TRUE) configs(learning.test, all = FALSE)
Run the code above in your browser using DataLab